package com.magnifyb.api.authenticationcontroller;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.hamcrest.Matchers;
import org.json.JSONException;
import org.json.JSONObject;
import org.testng.annotations.Test;

import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import io.restassured.specification.RequestSpecification;

public class AuthenticationController {

	RequestSpecification requestSpecification;
	Response response;
	ValidatableResponse validatableResponse;
	private static Properties properties;

	static {
		try {
			properties = new Properties();
			String userDir = System.getProperty("user.dir");
			FileInputStream input = new FileInputStream(userDir + "/src/test/java/properties/config.properties");
			properties.load(input);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	@Test
	public void login() throws JSONException {

		String username = properties.getProperty("username");
		String password = properties.getProperty("password");

		JSONObject json = new JSONObject();
		json.put("username", username);
		json.put("password", password);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/login";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);

		// Check response body - username attribute
		validatableResponse.body("data.username", Matchers.is(username));
	}

}
