package com.magnifyb.api.companyinfocontroller;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.json.JSONException;
import org.json.JSONObject;
import org.testng.Assert;
import org.testng.annotations.Test;

import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import io.restassured.specification.RequestSpecification;

public class CompanyInfoController {
	private static Properties properties;
	Response response;

	static {
		try {
			properties = new Properties();
			String userDir = System.getProperty("user.dir");
			FileInputStream input = new FileInputStream(userDir + "/src/test/java/properties/config.properties");
			properties.load(input);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	@Test
	public void dashboard_months_balance() {
		String baseUrl = properties.getProperty("base_url");
		String userID = properties.getProperty("userId");
		response = RestAssured.get(baseUrl + "/financial_year_flag/" + userID);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void get_all_companies() {
		String baseUrl = properties.getProperty("base_url");
		response = RestAssured.get(baseUrl + "/get_all_companies");
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void get_company_by_username() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		Response response = RestAssured.get(baseUrl + "/get_company_by_username/" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void get_company_list_by_id() {
		String baseUrl = properties.getProperty("base_url");
		String id = properties.getProperty("id");
		response = RestAssured.get(baseUrl + "/get_company_list_by_id/" + id);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void save_company() throws JSONException {

		String addressLine = properties.getProperty("addressLine");
		String city = properties.getProperty("city");
		String companyName = properties.getProperty("companyName");
		String companyRegistrationNumber = properties.getProperty("companyRegistrationNumber");
		String companyType = properties.getProperty("companyType");
		String email = properties.getProperty("email2");
		String firstName = properties.getProperty("firstName");
		String isAdmin = properties.getProperty("isAdmin");
		String isPremium = properties.getProperty("isPremium");
		String lastName = properties.getProperty("lastName");
		String marketingPermission = properties.getProperty("marketingPermission");
		String password = properties.getProperty("password");
		String phone = properties.getProperty("phone");
		String postCode = properties.getProperty("postCode");
		String privacyNotice = properties.getProperty("privacyNotice");
		String sector = properties.getProperty("sector");
		String streetAddress = properties.getProperty("streetAddress");
		String subscriptionType = properties.getProperty("subscriptionType");
		String termsAndConditions = properties.getProperty("termsAndConditions");
		String webAddress = properties.getProperty("webAddress");

		JSONObject json = new JSONObject();
		json.put("addressLine", addressLine);
		json.put("city", city);
		json.put("companyName", companyName);
		json.put("companyRegistrationNumber", companyRegistrationNumber);
		json.put("companyType", companyType);
		json.put("email", email);
		json.put("firstName", firstName);
		json.put("isAdmin", isAdmin);
		json.put("isPremium", isPremium);
		json.put("lastName", lastName);
		json.put("marketingPermission", marketingPermission);
		json.put("password", password);
		json.put("phone", phone);
		json.put("postCode", postCode);
		json.put("privacyNotice", privacyNotice);
		json.put("sector", sector);
		json.put("streetAddress", streetAddress);
		json.put("subscriptionType", subscriptionType);
		json.put("termsAndConditions", termsAndConditions);
		json.put("webAddress", webAddress);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/save_company";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);

	}

	@Test
	public void save_financial_end_month() {
		String baseUrl = properties.getProperty("base_url");
		String userId = properties.getProperty("userId");
		String endMonth = properties.getProperty("endMonth");
		response = RestAssured.get(baseUrl + "/save_financial_end_month/" + userId + "/" + endMonth);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

}
