package com.magnifyb.api.contactuscontroller;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.hamcrest.Matchers;
import org.json.JSONException;
import org.json.JSONObject;
import org.testng.annotations.Test;

import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import io.restassured.specification.RequestSpecification;

public class ContactUsController {

	private static Properties properties;
	RequestSpecification requestSpecification;
	Response response;
	ValidatableResponse validatableResponse;

	static {
		try {
			properties = new Properties();
			String userDir = System.getProperty("user.dir");
			FileInputStream input = new FileInputStream(userDir + "/src/test/java/properties/config.properties");
			properties.load(input);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	@Test
	public void contact_us() throws JSONException {

		String answersText = properties.getProperty("answersText");
		String companyName = properties.getProperty("companyName");
		String date = properties.getProperty("date");
		String day = properties.getProperty("day");
		String hours = properties.getProperty("hours");
		String minutes = properties.getProperty("minutes");
		String nanos = properties.getProperty("nanos");
		String seconds = properties.getProperty("seconds");
		String time = properties.getProperty("time");
		String timezoneOffset = properties.getProperty("timezoneOffset");
		String year = properties.getProperty("year");
		String email = properties.getProperty("email");
		String id = properties.getProperty("id");
		String name = properties.getProperty("name");
		String questions = properties.getProperty("questions");

		JSONObject json = new JSONObject();
		json.put("answersText", answersText);
		json.put("companyName", companyName);
		json.put("date", date);
		json.put("day", day);
		json.put("hours", hours);
		json.put("minutes", minutes);
		json.put("nanos", nanos);
		json.put("seconds", seconds);
		json.put("time", time);
		json.put("timezoneOffset", timezoneOffset);
		json.put("year", year);
		json.put("email", email);
		json.put("id", id);
		json.put("name", name);
		json.put("questions", questions);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/contact_us";

		// Create a request specification
		requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		response = requestSpecification.post();
		
		// Print the entire response body
		System.out.println(response.body().asString());


		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
		validatableResponse.body("responseMessage", Matchers.is("ContactUs saved Successfully"));
	}

}
