package com.magnifyb.api.detailedplcontroller;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.json.JSONException;
import org.json.JSONObject;
import org.testng.Assert;
import org.testng.annotations.Test;

import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import io.restassured.specification.RequestSpecification;

public class DetailedPLController {
	private static Properties properties;
	RequestSpecification requestSpecification;
	Response response;
	ValidatableResponse validatableResponse;

	static {
		try {
			properties = new Properties();
			String userDir = System.getProperty("user.dir");
			FileInputStream input = new FileInputStream(userDir + "/src/test/java/properties/config.properties");
			properties.load(input);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	  @Test(enabled = false)
	public void detail_profit_loss_changes() throws JSONException {

		String changePercentage = properties.getProperty("changePercentage");
		String cumulativePlMonths = properties.getProperty("cumulativePlMonths");
		String cumulativePlValue = properties.getProperty("cumulativePlValue");
		String productName = properties.getProperty("productName");
		String typeKeyword = properties.getProperty("typeKeyword");

		JSONObject json = new JSONObject();
		json.put("changePercentage", changePercentage);
		json.put("cumulativePlMonths", cumulativePlMonths);
		json.put("cumulativePlValue", cumulativePlValue);
		json.put("productName", productName);
		json.put("typeKeyword", typeKeyword);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/detail_profit_loss_changes";

		// Create a request specification
		requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		response = requestSpecification.post();

		// Print the entire response body
		System.out.println(response.body().asString());

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void get_detail_profit_loss_values() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		response = RestAssured.get(baseUrl + "/get_detail_profit_loss_values/" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);
	}

	  @Test(enabled = false)
	public void save_detail_profit_loss() throws JSONException {

		String annualizedPlMonths = properties.getProperty("annualizedPlMonths");
		String cumulativePlMonths = properties.getProperty("cumulativePlMonths");
		String cumulativePlValue = properties.getProperty("cumulativePlValue");
		String information_from = properties.getProperty("information_from");
		String productName = properties.getProperty("productName");
		String type = properties.getProperty("typeKeyword");
		String userId = properties.getProperty("userId");

		JSONObject json = new JSONObject();
		json.put("annualizedPlMonths", annualizedPlMonths);
		json.put("cumulativePlMonths", cumulativePlMonths);
		json.put("cumulativePlValue", cumulativePlValue);
		json.put("information_from", information_from);
		json.put("productName", productName);
		json.put("type", type);
		json.put("userId", userId);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/save_detail_profit_loss";

		// Create a request specification
		requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		response = requestSpecification.post();

		// Print the entire response body
//		System.out.println(response.body().asString());

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

}
