package com.magnifyb.api.signupcontroller;

import java.io.FileInputStream;
import java.io.IOException;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.Properties;

import org.json.JSONException;
import org.json.JSONObject;
import org.testng.Assert;
import org.testng.annotations.Test;

import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import io.restassured.specification.RequestSpecification;

public class SignUpController {
	private static Properties properties;
	RequestSpecification requestSpecification;
	Response response;
	ValidatableResponse validatableResponse;

	static {
		try {
			properties = new Properties();
			String userDir = System.getProperty("user.dir");
			FileInputStream input = new FileInputStream(userDir + "/src/test/java/properties/config.properties");
			properties.load(input);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	@Test
	public void get_chapter_questions_details() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		response = RestAssured.get(baseUrl + "/dashboard_myfinance_flag/" + username + "?dashboardLogin=" + username
				+ "&" + "myFinanceLogin=" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test(enabled = false)
	public void login() throws JSONException {

		String email = properties.getProperty("email");

		JSONObject json = new JSONObject();
		json.put("email", email);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/forgot_password/" + email;

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void generate_access_code() throws JSONException {

		String businessName = properties.getProperty("businessName");
		String email = properties.getProperty("email");
		String firstName = properties.getProperty("firstName");
		String lastName = properties.getProperty("lastName");
		String marketingPermission = properties.getProperty("marketingPermission");
		String mobileNumber = properties.getProperty("mobileNumber");
		String privacyNotice = properties.getProperty("privacyNotice");

		JSONObject json = new JSONObject();
		json.put("businessName", businessName);
		json.put("email", email);
		json.put("firstName", firstName);
		json.put("lastName", lastName);
		json.put("marketingPermission", marketingPermission);
		json.put("mobileNumber", mobileNumber);
		json.put("privacyNotice", privacyNotice);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/generate_access_code";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void get_dashboard_myfinance_flag() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		response = RestAssured.get(baseUrl + "/get_dashboard_myfinance_flag/" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void get_signup_progress_details() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		response = RestAssured.get(baseUrl + "/get_signup_progress_details/" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void issues_enquiry_for_signup() throws JSONException {

		String businessName = properties.getProperty("businessName");
		String email = properties.getProperty("email");
		String id = properties.getProperty("id");
		String issueOrEnquiryType = properties.getProperty("issueOrEnquiryType");
		String firstName = properties.getProperty("firstName");
		String lastName = properties.getProperty("lastName");
		String marketingPermission = properties.getProperty("marketingPermission");
		String mobileNumber = properties.getProperty("mobileNumber");
		String privacyNotice = properties.getProperty("privacyNotice");

		JSONObject json = new JSONObject();
		json.put("businessName", businessName);
		json.put("email", email);
		json.put("firstName", firstName);
		json.put("id", id);
		json.put("issueOrEnquiryType", issueOrEnquiryType);
		json.put("lastName", lastName);
		json.put("marketingPermission", marketingPermission);
		json.put("mobileNumber", mobileNumber);
		json.put("privacyNotice", privacyNotice);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/issues_enquiry_for_signup";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void new_signin() throws JSONException {

		String password = properties.getProperty("password");
		String username = properties.getProperty("username");

		JSONObject json = new JSONObject();
		json.put("password", password);
		json.put("username", username);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/new_signin";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void passcode_authentication() {
		String baseUrl = properties.getProperty("base_url");
		String email = properties.getProperty("email");
		String passcode = properties.getProperty("passcode");
		response = RestAssured.get(baseUrl + "/passcode_authentications/" + email +"/"+ passcode);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void reset_password() throws JSONException {
		String newPassword = properties.getProperty("newPassword");
		String password = properties.getProperty("password");
		String userName = properties.getProperty("email");

		JSONObject json = new JSONObject();
		json.put("newPassword", newPassword);
		json.put("password", password);
		json.put("userName", userName);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/reset_password";

		String responseBody = response.getBody().asPrettyString();
		System.out.println("Response Body: " + responseBody);

		// Create a request specification
		requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void save_forgot_password() throws JSONException {
		String email = properties.getProperty("email");
		String passcode = properties.getProperty("passcode");
		String password = properties.getProperty("password");

		JSONObject json = new JSONObject();
		json.put("email", email);
		json.put("passcode", passcode);
		json.put("password", password);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/save_forgot_password";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void save_signup_progress() throws JSONException {

		String dashboardFlag = properties.getProperty("dashboardFlag");
		String detailedQuestionFlag = properties.getProperty("detailedQuestionFlag");
		String earlyLaunchScreenFlag = properties.getProperty("earlyLaunchScreenFlag");
		String emailVerificationScreenFlag = properties.getProperty("emailVerificationScreenFlag");
		String financeQuestionsFlag = properties.getProperty("financeQuestionsFlag");
		String financeSummapasscoderyFlag = properties.getProperty("financeSummapasscoderyFlag");
		String financeSystemScreenFlag = properties.getProperty("financeSystemScreenFlag");
		String genericScreenFlag = properties.getProperty("genericScreenFlag");
		String id = properties.getProperty("id");
		String mangnifybBenifitsFlag = properties.getProperty("mangnifybBenifitsFlag");
		String progressScreenFlag = properties.getProperty("progressScreenFlag");
		String thankYouScreenFlag = properties.getProperty("thankYouScreenFlag");
		String username = properties.getProperty("username");

		JSONObject json = new JSONObject();
		json.put("dashboardFlag", dashboardFlag);
		json.put("detailedQuestionFlag", detailedQuestionFlag);
		json.put("earlyLaunchScreenFlag", earlyLaunchScreenFlag);
		json.put("emailVerificationScreenFlag", emailVerificationScreenFlag);
		json.put("financeQuestionsFlag", financeQuestionsFlag);
		json.put("financeSummapasscoderyFlag", financeSummapasscoderyFlag);
		json.put("financeSystemScreenFlag", financeSystemScreenFlag);
		json.put("genericScreenFlag", genericScreenFlag);
		json.put("id", id);
		json.put("mangnifybBenifitsFlag", mangnifybBenifitsFlag);
		json.put("progressScreenFlag", progressScreenFlag);
		json.put("thankYouScreenFlag", thankYouScreenFlag);
		json.put("username", username);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/save_signup_progress";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void signup() throws JSONException {

		String addressLine = properties.getProperty("addressLine");
		String city = properties.getProperty("city");
		String companyName = properties.getProperty("companyName");
		String companyRegistrationNumber = properties.getProperty("companyRegistrationNumber");
		String companyType = properties.getProperty("companyType");
		String email = properties.getProperty("email2");
		String firstName = properties.getProperty("firstName");
		String isAdmin = properties.getProperty("isAdmin");
		String isPremium = properties.getProperty("isPremium");
		String lastName = properties.getProperty("lastName");
		String marketingPermission = properties.getProperty("marketingPermission");
		String password = properties.getProperty("password");
		String phone = properties.getProperty("phone");
		String postCode = properties.getProperty("postCode");	
		String privacyNotice = properties.getProperty("privacyNotice");
		String sector = properties.getProperty("sector");
		String streetAddress = properties.getProperty("streetAddress");
		String subscriptionType = properties.getProperty("subscriptionType");
		String termsAndConditions = properties.getProperty("termsAndConditions");
		String webAddress = properties.getProperty("webAddress");

		JSONObject json = new JSONObject();
		json.put("addressLine", addressLine);
		json.put("city", city);
		json.put("companyName", companyName);
		json.put("companyRegistrationNumber", companyRegistrationNumber);
		json.put("companyType", companyType);
		json.put("email", email);
		json.put("firstName", firstName);
		json.put("isAdmin", isAdmin);
		json.put("isPremium", isPremium);
		json.put("lastName", lastName);
		json.put("marketingPermission", marketingPermission);
		json.put("password", password);
		json.put("phone", phone);
		json.put("postCode", postCode);
		json.put("privacyNotice", privacyNotice);
		json.put("sector", sector);
		json.put("streetAddress", streetAddress);
		json.put("subscriptionType", subscriptionType);
		json.put("termsAndConditions", termsAndConditions);
		json.put("webAddress", webAddress);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/signup";

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

	@Test
	public void specific_count() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		response = RestAssured.get(baseUrl + "/specific_count/" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void user_check() {
		String baseUrl = properties.getProperty("base_url");
		String email = properties.getProperty("email");
		response = RestAssured.get(baseUrl + "/user_check/" + email);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void validate_access_code() {
		String baseUrl = properties.getProperty("base_url");
		String accessCode = properties.getProperty("accessCode");
		response = RestAssured.get(baseUrl + "/validate_access_code/" + accessCode);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}

	@Test
	public void verify_email() throws JSONException {

		String email = properties.getProperty("useremail");

		JSONObject json = new JSONObject();
		json.put("email", email);

		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");

		// Ensure proper URL encoding of the email
		String encodedEmail = URLEncoder.encode(email, StandardCharsets.UTF_8);

		// Update the base URI
		RestAssured.baseURI = baseUrl + "/verify_email/" + encodedEmail;

//		RestAssured.baseURI = baseUrl + "/verify_email/" + email;

		// Create a request specification
		RequestSpecification requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		Response response = requestSpecification.post();

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		ValidatableResponse validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}

}
