package com.magnifyb.api.slidercalculatorcontroller;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.json.JSONException;
import org.json.JSONObject;
import org.testng.Assert;
import org.testng.annotations.Test;

import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import io.restassured.specification.RequestSpecification;

public class SliderCalculatorController {

	private static Properties properties;
	RequestSpecification requestSpecification;
	Response response;
	ValidatableResponse validatableResponse;

	static {
		try {
			properties = new Properties();
			String userDir = System.getProperty("user.dir");
			FileInputStream input = new FileInputStream(userDir + "/src/test/java/properties/config.properties");
			properties.load(input);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	@Test
	public void get_balance_sheet_new() throws JSONException {
		
		String costOfSales = properties.getProperty("BLcostOfSales");
		String currentBalanceSheetFigureInStock = properties.getProperty("currentBalanceSheetFigureInStock");
		String currentBalanceSheetFigureInTradeCreditors = properties.getProperty("currentBalanceSheetFigureInTradeCreditors");
		String currentBalanceSheetFigureInTradeDebtors = properties.getProperty("currentBalanceSheetFigureInTradeDebtors");
		String increaseSTockTurnByPercentage = properties.getProperty("increaseSTockTurnByPercentage");
		String negotiate60DayTerms = properties.getProperty("negotiate60DayTerms");
		String noOfMonthsThisYear = properties.getProperty("noOfMonthsThisYear");
		String sales = properties.getProperty("sales");
		String targetDebtorDays = properties.getProperty("targetDebtorDays");
		String username = properties.getProperty("username");
		String vatRatio = properties.getProperty("vatRatio");

		JSONObject json = new JSONObject();
		json.put("costOfSales", costOfSales);
		json.put("currentBalanceSheetFigureInStock", currentBalanceSheetFigureInStock);
		json.put("currentBalanceSheetFigureInTradeCreditors", currentBalanceSheetFigureInTradeCreditors);
		json.put("currentBalanceSheetFigureInTradeDebtors", currentBalanceSheetFigureInTradeDebtors);
		json.put("increaseSTockTurnByPercentage", increaseSTockTurnByPercentage);
		json.put("negotiate60DayTerms", negotiate60DayTerms);
		json.put("noOfMonthsThisYear", noOfMonthsThisYear);
		json.put("sales", sales);
		json.put("targetDebtorDays", targetDebtorDays);
		json.put("username", username);
		json.put("vatRatio", vatRatio);


		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/get_balance_sheet_new";

		// Create a request specification
		requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		response = requestSpecification.post();

		// Print the entire response body
		System.out.println(response.body().asString());

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}
	
	@Test
	public void get_balancesheet_levers_values() {
		String baseUrl = properties.getProperty("base_url");
		String username = properties.getProperty("username");
		 response = RestAssured.get(baseUrl + "/get_balancesheet_levers_values/" + username);
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}
	
	@Test
	public void get_default_slider_values() {
		String baseUrl = properties.getProperty("base_url");
		 response = RestAssured.get(baseUrl + "/get_default_slider_values" );
//		System.out.println(response.statusCode());
//		System.out.println(response.getBody().asString());
		int statusCode = response.getStatusCode();
		Assert.assertEquals(statusCode, 200);

	}
	
	@Test
	public void new_slider_value_change() throws JSONException {
		
		String costOfSalesChangeValue = properties.getProperty("costOfSalesChangeValue");
		String costOfSalesLastYear = properties.getProperty("costOfSalesLastYear");
		String costOfSalesReduction = properties.getProperty("costOfSalesReduction");
		String costOfSalesYTD = properties.getProperty("costOfSalesYTD");
		String currentCostOfSales = properties.getProperty("currentCostOfSales");
		String currentOverheads = properties.getProperty("currentOverheads");
		String currentPayroll = properties.getProperty("currentPayroll");
		String currentPrice = properties.getProperty("currentPrice");
		String currentSales = properties.getProperty("currentSales");
		String noOfMonthsLastYear = properties.getProperty("noOfMonthsLastYear");
		String noOfMonthsThisYear = properties.getProperty("noOfMonthsThisYear");	
		String overheadChangeValue = properties.getProperty("overheadChangeValue");
		String overheadCostsLastYear = properties.getProperty("overheadCostsLastYear");
		String overheadCostsYTD = properties.getProperty("overheadCostsYTD");
		String overheadReduction = properties.getProperty("overheadReduction");
		String payrollChangeValue = properties.getProperty("payrollChangeValue");
		String payrollCostLastYear = properties.getProperty("payrollCostLastYear");
		String payrollReduction = properties.getProperty("payrollReduction");
		String payrollYTD = properties.getProperty("payrollYTD");
		String priceIncrease = properties.getProperty("priceIncrease");
		String revisedCostOfSalesPercentageValue = properties.getProperty("revisedCostOfSalesPercentageValue");
		String revisedCostOfSalesValue = properties.getProperty("revisedCostOfSalesValue");	
		String revisedOverheadPercentageValue = properties.getProperty("revisedOverheadPercentageValue");
		String revisedOverheadValue = properties.getProperty("revisedOverheadValue");
		String revisedPayrollPercentageValue = properties.getProperty("revisedPayrollPercentageValue");
		String revisedPayrollValue = properties.getProperty("revisedPayrollValue");
		String revisedSaleValue = properties.getProperty("revisedSaleValue");
		String revisedSalesPercentageValue = properties.getProperty("revisedSalesPercentageValue");
		String salesChangeValue = properties.getProperty("salesChangeValue");
		String salesGrowth = properties.getProperty("salesGrowth");
		String salesLastYear = properties.getProperty("salesLastYear");
		String salesYTD = properties.getProperty("salesYTD");
		String sliderKeyword = properties.getProperty("sliderKeyword");

		JSONObject json = new JSONObject();
		json.put("costOfSalesChangeValue", costOfSalesChangeValue);
		json.put("costOfSalesLastYear", costOfSalesLastYear);
		json.put("costOfSalesReduction", costOfSalesReduction);
		json.put("costOfSalesYTD", costOfSalesYTD);
		json.put("currentCostOfSales", currentCostOfSales);
		json.put("currentOverheads", currentOverheads);
		json.put("currentPayroll", currentPayroll);
		json.put("currentPrice", currentPrice);
		json.put("currentSales", currentSales);
		json.put("noOfMonthsLastYear", noOfMonthsLastYear);
		json.put("noOfMonthsThisYear", noOfMonthsThisYear);	
		json.put("overheadChangeValue", overheadChangeValue);
		json.put("overheadCostsLastYear", overheadCostsLastYear);
		json.put("overheadCostsYTD", overheadCostsYTD);
		json.put("overheadReduction", overheadReduction);
		json.put("payrollChangeValue", payrollChangeValue);
		json.put("payrollCostLastYear", payrollCostLastYear);
		json.put("payrollReduction", payrollReduction);
		json.put("payrollYTD", payrollYTD);
		json.put("priceIncrease", priceIncrease);
		json.put("revisedCostOfSalesPercentageValue", revisedCostOfSalesPercentageValue);
		json.put("revisedCostOfSalesValue", revisedCostOfSalesValue);
		json.put("revisedOverheadPercentageValue", revisedOverheadPercentageValue);
		json.put("revisedOverheadValue", revisedOverheadValue);
		json.put("revisedPayrollPercentageValue", revisedPayrollPercentageValue);
		json.put("revisedPayrollValue", revisedPayrollValue);
		json.put("revisedSaleValue", revisedSaleValue);
		json.put("revisedSalesPercentageValue", revisedSalesPercentageValue);
		json.put("salesChangeValue", salesChangeValue);
		json.put("salesGrowth", salesGrowth);
		json.put("salesLastYear", salesLastYear);
		json.put("salesYTD", salesYTD);
		json.put("sliderKeyword", sliderKeyword);


		// Convert JSONObject to a string
		String jsonString = json.toString();

		String baseUrl = properties.getProperty("base_url");
		RestAssured.baseURI = baseUrl + "/new_slider_value_change";

		// Create a request specification
		requestSpecification = RestAssured.given();

		// Setting content type to specify the format in which the request payload will
		// be sent.
		requestSpecification.contentType(ContentType.JSON);

		// Adding body as a string
		requestSpecification.body(jsonString); // Use the jsonString here

		// Calling POST method
		response = requestSpecification.post();

		// Print the entire response body
		System.out.println(response.body().asString());

		/*
		 * To perform validation on the response, we need to get ValidatableResponse
		 * type of response
		 */
		validatableResponse = response.then();

		// Check status code
		validatableResponse.statusCode(200);
	}
	
}
